Executes one stage or a full workflow from a JSON spec or spec object.
Usage
run_pipeline(
spec,
stage = c("import", "features", "train", "optimise", "predict", "export", "all")
)Executes one stage or a full workflow from a JSON spec or spec object.
run_pipeline(
spec,
stage = c("import", "features", "train", "optimise", "predict", "export", "all")
)