Interactively builds a simple import spec, previews the canonicalised data, and writes the run spec into the current workspace.
Interactively builds a simple import spec, previews the canonicalised data, and writes the run spec into the current workspace.