Writes a deployable model bundle containing the trained model, specs, feature manifest, metrics, plots, and test vectors.
Arguments
- spec
A
moover_specobject or path to a JSON spec.- fitted_model
Optional result from
train_model(). IfNULL, the cached fit for the run is used.