Reads configured raw files, converts them to the canonical id, t_unix_ms,
x, y, z layout, and writes preview and summary artefacts into the run.
Reads configured raw files, converts them to the canonical id, t_unix_ms,
x, y, z layout, and writes preview and summary artefacts into the run.