Applies an exported model bundle to new raw accelerometer data and writes epoch-level predictions into the current run.
Arguments
- spec
A
moover_specobject or path to a JSON spec.- model_bundle
A bundle object returned by
load_model_bundle()or a path to an exported model bundle directory. IfNULL,spec$predict$model_bundleis used.