R/model_workflows.R
train_model.Rd
Trains a Random Forest model either from the selected optimisation candidate or from the feature/model settings in the spec.
train_model(spec)
A moover_spec object or path to a JSON spec.
moover_spec
A fitted model bundle stored in the run cache and returned as a list.